NubrickDispatcher class

NubrickDispatcher is the main dispatcher for the Nubrick SDK.

reference: https://docs.nubrick.app/reference/flutter/nubrickdispatcher

Usage:

NubrickDispatcher.instance.dispatch(NubrickEvent('event_name'));

Constructors

NubrickDispatcher()
Creates a new instance of NubrickDispatcher.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispatch(NubrickEvent event) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance NubrickDispatcher
The singleton instance of NubrickDispatcher.
no setter