nubrick_flutter library

Classes

Event
EventPayload
Nubrick
A bridge client to the nubrick SDK.
NubrickAnchor
A widget that acts as an anchor point for tooltips or onboarding stories in the Nubrick dashboard.
NubrickDispatcher
NubrickDispatcher is the main dispatcher for the Nubrick SDK.
NubrickEmbedding
A widget that embeds an experiment.
NubrickEvent
NubrickFillSize
NubrickFixedSize
NubrickProvider
NubrickProvider is the main provider for the Nubrick SDK.
NubrickProviderState
NubrickRemoteConfig
A remote config that can be fetched from nubrick.
NubrickRemoteConfigVariant
NubrickSize
NubrickUser
A class to handle NubrickUser.

Extensions

NubrickInstanceCompatibility on Nubrick
NubrickProviderExtension on BuildContext
Extension to access NubrickProvider from build context

Typedefs

EmbeddingBuilder = Widget Function(BuildContext context, EmbeddingPhase phase, Widget child)
EmbeddingSizeHandler = void Function(NubrickSize width, NubrickSize height)
EventHandler = void Function(Event event)