ExperimentFrequency class

Constructors

ExperimentFrequency({int? period, FrequencyUnit? unit})

Properties

hashCode → int
The hash code for this object.
no setterinherited
period → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → FrequencyUnit?
final

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → ExperimentFrequency?