ExperimentVariant class

Constructors

ExperimentVariant({String? id, String? label, List<VariantConfig>? configs, int? weight})

Properties

configs → List<VariantConfig>?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
label → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → int?
final

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → ExperimentVariant?