FrameData class

Constructors

FrameData({int? width, int? height, int? paddingLeft, int? paddingRight, int? paddingTop, int? paddingBottom, int? borderRadius, int? borderTopLeftRadius, int? borderTopRightRadius, int? borderBottomRightRadius, int? borderBottomLeftRadius, int? borderWidth, ColorValue? borderColor, ColorValue? background, String? backgroundSrc, BoxShadow? shadow})

Properties

background → ColorValue?
final
backgroundSrc → String?
final
borderBottomLeftRadius → int?
final
borderBottomRightRadius → int?
final
borderColor → ColorValue?
final
borderRadius → int?
final
borderTopLeftRadius → int?
final
borderTopRightRadius → int?
final
borderWidth → int?
final
hashCode → int
The hash code for this object.
no setterinherited
height → int?
final
paddingBottom → int?
final
paddingLeft → int?
final
paddingRight → int?
final
paddingTop → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow → BoxShadow?
final
width → int?
final

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → FrameData?