LinearGradient class

Constructors

LinearGradient({double? red, double? green, double? blue, double? alpha, double? angle, List<GradientStop>? stops})

Properties

alpha → double?
final
angle → double?
final
blue → double?
final
green → double?
final
hashCode → int
The hash code for this object.
no setterinherited
red → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stops → List<GradientStop>?
final

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → LinearGradient?