UICarouselBlockData class

Constructors

UICarouselBlockData({List<UIBlock>? children, FrameData? frame, int? gap, UIBlockAction? onClick})

Properties

children → List<UIBlock>?
final
frame → FrameData?
final
gap → int?
final
hashCode → int
The hash code for this object.
no setterinherited
onClick → UIBlockAction?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → UICarouselBlockData?