UIFlexContainerBlockData class

Constructors

UIFlexContainerBlockData({List<UIBlock>? children, FlexDirection? direction, JustifyContent? justifyContent, AlignItems? alignItems, int? gap, FrameData? frame, Overflow? overflow, UIBlockAction? onClick})

Properties

alignItems → AlignItems?
final
children → List<UIBlock>?
final
direction → FlexDirection?
final
frame → FrameData?
final
gap → int?
final
hashCode → int
The hash code for this object.
no setterinherited
justifyContent → JustifyContent?
final
onClick → UIBlockAction?
final
overflow → Overflow?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → UIFlexContainerBlockData?