UIPageBlockData class

Constructors

UIPageBlockData({PageKind? kind, ModalPresentationStyle? modalPresentationStyle, ModalScreenSize? modalScreenSize, NavigationBackButton? modalNavigationBackButton, bool? modalRespectSafeArea, String? webviewUrl, TriggerSetting? triggerSetting, UIBlock? renderAs, UIPageBlockPosition? position, ApiHttpRequest? httpRequest, UITooltipSize? tooltipSize, String? tooltipAnchor, UITooltipPlacement? tooltipPlacement, UITooltipTransitionTarget? tooltipTransitionTarget, List<Property>? props, int? frameWidth, int? frameHeight, String? query})

Properties

frameHeight → int?
final
frameWidth → int?
final
hashCode → int
The hash code for this object.
no setterinherited
httpRequest → ApiHttpRequest?
final
kind → PageKind?
final
modalNavigationBackButton → NavigationBackButton?
final
modalPresentationStyle → ModalPresentationStyle?
final
modalRespectSafeArea → bool?
final
modalScreenSize → ModalScreenSize?
final
position → UIPageBlockPosition?
final
props → List<Property>?
final
query → String?
final
renderAs → UIBlock?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tooltipAnchor → String?
final
tooltipPlacement → UITooltipPlacement?
final
tooltipSize → UITooltipSize?
final
tooltipTransitionTarget → UITooltipTransitionTarget?
final
triggerSetting → TriggerSetting?
final
webviewUrl → String?
final

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → UIPageBlockData?