UITextBlockData class

Constructors

UITextBlockData({String? value, int? size, double? lineHeight, ColorValue? color, FontDesign? design, FontWeight? weight, int? maxLines, bool? scaleWithDeviceFontSize, FrameData? frame, UIBlockAction? onClick})

Properties

color → ColorValue?
final
design → FontDesign?
final
frame → FrameData?
final
hashCode → int
The hash code for this object.
no setterinherited
lineHeight → double?
final
maxLines → int?
final
onClick → UIBlockAction?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleWithDeviceFontSize → bool?
final
size → int?
final
value → String?
final
weight → FontWeight?
final

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → UITextBlockData?