UITextInputBlockData class

Constructors

UITextInputBlockData({String? key, String? value, String? placeholder, String? regex, UITooltipMessage? errorMessage, UITextInputKeyboardType? keyboardType, bool? secure, bool? autocorrect, int? size, ColorValue? color, FontDesign? design, FontWeight? weight, TextAlign? textAlign, FrameData? frame})

Properties

autocorrect → bool?
final
color → ColorValue?
final
design → FontDesign?
final
errorMessage → UITooltipMessage?
final
frame → FrameData?
final
hashCode → int
The hash code for this object.
no setterinherited
key → String?
final
keyboardType → UITextInputKeyboardType?
final
placeholder → String?
final
regex → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secure → bool?
final
size → int?
final
textAlign → TextAlign?
final
value → String?
final
weight → FontWeight?
final

Methods

encode() → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(dynamic json) → UITextInputBlockData?