getId method

Future<String?> getId()

Retrieves the current user ID.

Returns a Future that completes with the user ID as a String, or null if no user ID is set.

Implementation

Future<String?> getId() async {
  if (!nubrickRuntime.isReady) {
    await nubrickRuntime.ready;
  }
  return await NubrickFlutterPlatform.instance.getUserId();
}